{% extends "base.html" %}
{% load i18n %}

{% block body %}
<b>{% trans "Create or change occurrence. All fields are required." %}</b>
<br><br>
<form action="" method="post">
  {% csrf_token %}
  <table>
    {{ form.as_table }}
  </table>
  <br>
  <input type="submit" value="{% trans "Save" %}">
  <input type="submit" name="cancel" value="Cancel">
</form>
{% endblock %}
