{% load i18n %}

<div style="display:none;" id="delete_dialog" title="Question">
  {% trans "Do you want to cancel this occurrence or delete all occurrences of this event?" %}
</div>

<div style="display:none;" id="edit_dialog" title="This is a recurring event">
  {% trans "Do you want to edit this occurrence or all occurrences?" %}
</div>
